@@ -1,7 +1,7 @@
 //go:build darwin && cgo
 
 /*
-Copyright © 2024 blacktop
+Copyright © 2025 blacktop
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -30,9 +30,11 @@ import (
 	"os"
 	"path/filepath"
 	"regexp"
+	"strings"
 
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
+	"github.com/blacktop/ipsw/pkg/dyld"
 	"github.com/blacktop/ipsw/pkg/info"
 	"github.com/blacktop/ipsw/pkg/ota/ridiff"
 	semver "github.com/hashicorp/go-version"
@@ -45,9 +47,15 @@ func init() {
 
 	otaPatchRsrCmd.Flags().StringP("input", "i", "", "Input folder")
 	otaPatchRsrCmd.Flags().StringP("output", "o", "", "Output folder")
+	otaPatchRsrCmd.Flags().StringArrayP("dyld-arch", "a", []string{}, "dyld_shared_cache architecture to extract")
+	otaPatchRsrCmd.RegisterFlagCompletionFunc("dyld-arch", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		return dyld.DscArches, cobra.ShellCompDirectiveDefault
+	})
 	otaPatchRsrCmd.MarkFlagDirname("input")
+	otaPatchRsrCmd.MarkFlagDirname("output")
 	viper.BindPFlag("ota.patch.input", otaPatchRsrCmd.Flags().Lookup("input"))
 	viper.BindPFlag("ota.patch.output", otaPatchRsrCmd.Flags().Lookup("output"))
+	viper.BindPFlag("ota.patch.dyld-arch", otaPatchRsrCmd.Flags().Lookup("dyld-arch"))
 }
 
 // otaPatchRsrCmd represents the rsr command
@@ -66,8 +74,20 @@ var otaPatchRsrCmd = &cobra.Command{
 			patchVerbose = 5
 		}
 
+		// flags
 		inFolder := viper.GetString("ota.patch.input")
 		outFolder := viper.GetString("ota.patch.output")
+		dyldArches := viper.GetStringSlice("ota.patch.dyld-arch")
+		// validate flags
+		if len(dyldArches) > 0 {
+			for _, arch := range dyldArches {
+				if !utils.StrSliceHas(dyld.DscArches, arch) {
+					return fmt.Errorf("invalid --dyld-arch: '%s' (must be one of %s)",
+						arch,
+						strings.Join(dyld.DscArches, ", "))
+				}
+			}
+		}
 
 		// check if we are running on compatible macOS version
 		host, err := utils.GetBuildInfo()
@@ -156,51 +176,57 @@ var otaPatchRsrCmd = &cobra.Command{
 				if err := ridiff.RawImagePatch(inDMG, pat.Name(), out, patchVerbose); err != nil {
 					return fmt.Errorf("failed to patch cryptex-app: %v", err)
 				}
-			} else if regexp.MustCompile(`cryptex-system-arm64?e$`).MatchString(zf.Name) {
-				systemDMG, err := i.GetSystemOsDmg()
-				if err != nil {
-					return fmt.Errorf("failed to get system DMG: %v", err)
+			} else {
+				re := regexp.MustCompile(`cryptex-system-(arm64e?|x86_64h?)$`)
+				if len(dyldArches) > 0 {
+					re = regexp.MustCompile(fmt.Sprintf(`cryptex-system-(%s)$`, strings.Join(dyldArches, "|")))
 				}
-
-				pat, err := os.CreateTemp("", "cryptex-system-arm64e")
-				if err != nil {
-					return fmt.Errorf("failed to create temp file for cryptex-system-arm64e: %v", err)
-				}
-				defer os.Remove(pat.Name())
-
-				f, err := zf.Open()
-				if err != nil {
-					return fmt.Errorf("failed to open cryptex-system-arm64e: %v", err)
-				}
-				defer f.Close()
-
-				io.Copy(pat, f)
-
-				out := filepath.Join(outFolder, "SystemOS", systemDMG)
-				if err := os.MkdirAll(filepath.Dir(out), 0750); err != nil {
-					return fmt.Errorf("failed to create SystemOS folder: %v", err)
-				}
-				if _, err := os.Create(out); err != nil {
-					return fmt.Errorf("failed to create SystemOS dmg: %v", err)
-				}
-
-				var inDMG string
-				if len(inFolder) > 0 {
-					matches, err := filepath.Glob(filepath.Join(inFolder, "SystemOS", "*.dmg"))
+				if re.MatchString(zf.Name) {
+					systemDMG, err := i.GetSystemOsDmg()
 					if err != nil {
-						return fmt.Errorf("failed to find SystemOS dmg in input folder: %v", err)
+						return fmt.Errorf("failed to get system DMG: %v", err)
 					}
-					if len(matches) == 0 {
-						return fmt.Errorf("failed to find SystemOS dmg (or found too many) to patch in input folder %s", inFolder)
-					} else if len(matches) > 1 {
-						return fmt.Errorf("found too many SystemOS DMGs (expected 1) to patch in input folder %s", inFolder)
-					}
-					inDMG = matches[0]
-				}
 
-				log.Infof("Patching cryptex-system-arm64e to %s", out)
-				if err := ridiff.RawImagePatch(inDMG, pat.Name(), out, patchVerbose); err != nil {
-					return fmt.Errorf("failed to patch cryptex-system-arm64e: %v", err)
+					pat, err := os.CreateTemp("", "cryptex-system")
+					if err != nil {
+						return fmt.Errorf("failed to create temp file for cryptex-system: %v", err)
+					}
+					defer os.Remove(pat.Name())
+
+					f, err := zf.Open()
+					if err != nil {
+						return fmt.Errorf("failed to open cryptex-system: %v", err)
+					}
+					defer f.Close()
+
+					io.Copy(pat, f)
+
+					out := filepath.Join(outFolder, "SystemOS", systemDMG)
+					if err := os.MkdirAll(filepath.Dir(out), 0750); err != nil {
+						return fmt.Errorf("failed to create SystemOS folder: %v", err)
+					}
+					if _, err := os.Create(out); err != nil {
+						return fmt.Errorf("failed to create SystemOS dmg: %v", err)
+					}
+
+					var inDMG string
+					if len(inFolder) > 0 {
+						matches, err := filepath.Glob(filepath.Join(inFolder, "SystemOS", "*.dmg"))
+						if err != nil {
+							return fmt.Errorf("failed to find SystemOS dmg in input folder: %v", err)
+						}
+						if len(matches) == 0 {
+							return fmt.Errorf("failed to find SystemOS dmg (or found too many) to patch in input folder %s", inFolder)
+						} else if len(matches) > 1 {
+							return fmt.Errorf("found too many SystemOS DMGs (expected 1) to patch in input folder %s", inFolder)
+						}
+						inDMG = matches[0]
+					}
+
+					log.Infof("Patching %s to %s", zf.Name, out)
+					if err := ridiff.RawImagePatch(inDMG, pat.Name(), out, patchVerbose); err != nil {
+						return fmt.Errorf("failed to patch %s: %v", zf.Name, err)
+					}
 				}
 			}
 		}
