@@ -44,41 +44,11 @@ func Extract(input, output string) ([]string, error) {
 		}
 		defer of.Close()
 
-		if len(bf.Segments) == 0 { // FIXME: should this be removed?
-			continue
-		}
-
-		if entry := bn.Config.TOC[idx].GetEntry(); entry != nil && entry.Type == 1 { // roottask (APP)
-			fname := filepath.Join(output, bf.Type, string(entry.Name.Bytes))
-			attr, err := os.Create(fname)
-			if err != nil {
-				return nil, fmt.Errorf("failed to create file %s: %v", fname, err)
-			}
-			defer attr.Close()
+		if idx == 0 { // SYSTEM/kernel
 			if _, err := f.Seek(int64(bn.Config.Assets[idx].Offset), io.SeekStart); err != nil {
 				return nil, fmt.Errorf("failed to seek to offset %d: %v", bn.Config.Assets[idx].Offset, err)
 			}
-			adata := make([]byte, bn.Config.Assets[idx].Size) // brkr_artifact
-			if err := binary.Read(f, binary.LittleEndian, &adata); err != nil {
-				return nil, fmt.Errorf("failed to read data from file %s: %v", fname, err)
-			}
-			// var brkr dict
-			// _, err := asn1.Unmarshal(adata, &brkr)
-			// if err != nil {
-			// 	return nil, fmt.Errorf("failed to unmarshal data from file %s: %v", fname, err)
-			// }
-			if _, err := attr.Write(adata); err != nil {
-				return nil, fmt.Errorf("failed to write data to file %s: %v", fname, err)
-			}
-			outfiles = append(outfiles, fname)
-		}
-
-		// Get MachO header
-		if entry := bn.Config.TOC[idx].GetEntry(); entry != nil && entry.Type == 2 { // kernel (SYSTEM)
-			if _, err := f.Seek(int64(bn.Config.Assets[idx].Offset), io.SeekStart); err != nil {
-				return nil, fmt.Errorf("failed to seek to offset %d: %v", bn.Config.Assets[idx].Offset, err)
-			}
-			mHdrData := make([]byte, bn.Config.Assets[idx].Size) // __MACHOHEADERLC
+			mHdrData := make([]byte, bn.Config.Assets[idx].Size)
 			if err := binary.Read(f, binary.LittleEndian, &mHdrData); err != nil {
 				return nil, fmt.Errorf("failed to read data from file %s: %v", fname, err)
 			}
@@ -88,50 +58,83 @@ func Extract(input, output string) ([]string, error) {
 			if err != nil {
 				return nil, fmt.Errorf("failed to parse MachO file: %v", err)
 			}
-			defer m.Close()
-			// write MACHOHEADERLC to output file
+			// write MACHOHEADERLC to kernel
 			if _, err := of.Write(mHdrData); err != nil {
 				return nil, fmt.Errorf("failed to write data to file %s: %v", fname, err)
 			}
 		} else {
-			if text := bf.Segment("TEXT"); text == nil {
-				return nil, fmt.Errorf("failed to find TEXT segment")
-			} else {
-				if _, err := f.Seek(int64(text.Offset), io.SeekStart); err != nil {
-					return nil, fmt.Errorf("failed to seek to offset %d: %v", text.Offset, err)
+			text := bf.Segment("TEXT")
+			if text == nil {
+				text = bf.Segment("HEADER")
+				if text == nil {
+					return nil, fmt.Errorf("failed to find TEXT segment")
 				}
-				tdata := make([]byte, text.Size)
-				if err := binary.Read(f, binary.LittleEndian, &tdata); err != nil {
-					return nil, fmt.Errorf("failed to read data from file %s: %v", fname, err)
-				}
-				m, err = macho.NewFile(bytes.NewReader(tdata), macho.FileConfig{
-					LoadIncluding: []types.LoadCmd{types.LC_SEGMENT_64},
-				})
-				if err != nil {
-					return nil, fmt.Errorf("failed to parse MachO file: %v", err)
-				}
-				defer m.Close()
+			}
+			if _, err := f.Seek(int64(text.Offset), io.SeekStart); err != nil {
+				return nil, fmt.Errorf("failed to seek to offset %d: %v", text.Offset, err)
+			}
+			tdata := make([]byte, text.Size)
+			if err := binary.Read(f, binary.LittleEndian, &tdata); err != nil {
+				return nil, fmt.Errorf("failed to read data from file %s: %v", fname, err)
+			}
+			m, err = macho.NewFile(bytes.NewReader(tdata), macho.FileConfig{
+				LoadIncluding: []types.LoadCmd{types.LC_SEGMENT_64},
+			})
+			if err != nil {
+				return nil, fmt.Errorf("failed to parse MachO file: %v", err)
 			}
 		}
-
-		for _, seg := range bf.Segments {
-			if _, err := f.Seek(int64(seg.Offset), io.SeekStart); err != nil {
-				return nil, fmt.Errorf("failed to seek to offset %d: %v", seg.Offset, err)
+		// write data to correct offsets
+		for _, sec := range bf.Sections {
+			if _, err := f.Seek(int64(sec.Offset), io.SeekStart); err != nil {
+				return nil, fmt.Errorf("failed to seek to offset %d in file %s: %v", sec.Offset, fname, err)
 			}
-			data := make([]byte, seg.Size)
+			data := make([]byte, sec.Size)
 			if err := binary.Read(f, binary.LittleEndian, &data); err != nil {
 				return nil, fmt.Errorf("failed to read data from file %s: %v", fname, err)
 			}
-			if s := m.Segment("__" + seg.Name); s == nil { // lookup segment in MachO header
-				return nil, fmt.Errorf("failed to find segment %s", seg.Name)
+			if s := m.Segment("__" + sec.Name); s == nil { // lookup segment in MachO header
+				return nil, fmt.Errorf("failed to find segment %s for %s", sec.Name, fname)
 			} else {
 				if _, err := of.WriteAt(data, int64(s.Offset)); err != nil {
 					return nil, fmt.Errorf("failed to write data to file %s: %v", fname, err)
 				}
 			}
 		}
+		m.Close()
 
 		outfiles = append(outfiles, fname)
+
+		/* ASSET file */
+		if entry := bn.Config.TOC[idx].GetEntry(); entry != nil && idx > 0 {
+			for _, asset := range bn.Config.Assets {
+				if entry.Type == asset.Type {
+					aname := fname + "." + string(entry.Name.Bytes)
+					attr, err := os.Create(aname)
+					if err != nil {
+						return nil, fmt.Errorf("failed to create file %s: %v", aname, err)
+					}
+					defer attr.Close()
+					if _, err := f.Seek(int64(asset.Offset), io.SeekStart); err != nil {
+						return nil, fmt.Errorf("failed to seek to offset %d: %v", asset.Offset, err)
+					}
+					adata := make([]byte, asset.Size) // brkr_artifact
+					if err := binary.Read(f, binary.LittleEndian, &adata); err != nil {
+						return nil, fmt.Errorf("failed to read data from file %s: %v", aname, err)
+					}
+					// TODO: parse 'brkr_artifact' which is a map[string]any or a plist essentially
+					// var brkr map[string]any
+					// if _, err := asn1.Unmarshal(adata, &brkr); err != nil {
+					// 	return nil, fmt.Errorf("failed to unmarshal data from file %s: %v", aname, err)
+					// }
+					// os.WriteFile(filepath.Join(output, bf.Type, "data.json"), adata, 0o644)
+					if _, err := attr.Write(adata); err != nil {
+						return nil, fmt.Errorf("failed to write data to file %s: %v", aname, err)
+					}
+					outfiles = append(outfiles, aname)
+				}
+			}
+		}
 	}
 
 	return outfiles, nil
