@@ -665,7 +665,7 @@ func (f *File) parseCache(r io.ReaderAt, uuid mtypes.UUID) error {
 		sr.Seek(int64(f.Headers[uuid].TPROMappingsOffset), io.SeekStart)
 		f.TPROMappings = make([]TPROMapping, f.Headers[uuid].TPROMappingsCount)
 		if err := binary.Read(sr, f.ByteOrder, f.TPROMappings); err != nil {
-			return fmt.Errorf("failed to read DSC TPRO mappings (new in iOS18.0beta1): %v", err)
+			return fmt.Errorf("failed to read DSC TPRO mappings (new in iOS18.0): %v", err)
 		}
 	}
 
